@@ -5,6 +5,7 @@ except ImportError:
     
 from menus.utils import set_language_changer
 
+from simple_translation.middleware import filter_queryset_language
 from simple_translation.utils import get_translation_filter
 from cmsplugin_blog.models import Entry
 
@@ -23,6 +24,7 @@ class EntryDateDetailView(DateDetailView):
         
     def get_queryset(self):
         queryset = super(EntryDateDetailView, self).get_queryset()
+        queryset = filter_queryset_language(self.request, queryset)
         if self.request.user.is_staff or self.request.user.is_superuser:
             return queryset
         else:
